summaryrefslogtreecommitdiffstats
path: root/host/include
diff options
context:
space:
mode:
Diffstat (limited to 'host/include')
-rw-r--r--host/include/uhd/types/metadata.hpp4
-rw-r--r--host/include/uhd/usrp/dsp_utils.hpp5
2 files changed, 3 insertions, 6 deletions
diff --git a/host/include/uhd/usrp/dsp_utils.hpp b/host/include/uhd/usrp/dsp_utils.hpp
index 8ec04dd2f..5b81ce322 100644
--- a/host/include/uhd/usrp/dsp_utils.hpp
+++ b/host/include/uhd/usrp/dsp_utils.hpp
@@ -85,12 +85,9 @@ namespace dsp_type1{
/*!
* Calculate the stream command word from the stream command struct.
* \param stream_cmd the requested stream command with mode, flags, timestamp
- * \param num_samps_continuous number of samples to request in continuous mode
* \return the 32-bit stream command word
*/
- UHD_API boost::uint32_t calc_stream_cmd_word(
- const stream_cmd_t &stream_cmd, size_t num_samps_continuous
- );
+ UHD_API boost::uint32_t calc_stream_cmd_word(const stream_cmd_t &stream_cmd);
} //namespace dsp_type1
diff --git a/host/include/uhd/types/metadata.hpp b/host/include/uhd/types/metadata.hpp
index 3f250d13e..f4e084430 100644
--- a/host/include/uhd/types/metadata.hpp
+++ b/host/include/uhd/types/metadata.hpp
@@ -132,8 +132,8 @@ namespace uhd{
* The type of event for a receive async message call.
*/
enum event_code_t {
- //! A packet was successfully transmitted.
- EVENT_CODE_SUCCESS = 0x1,
+ //! A burst was successfully transmitted.
+ EVENT_CODE_BURST_ACK = 0x1,
//! An internal send buffer has emptied.
EVENT_CODE_UNDERFLOW = 0x2,
//! Packet loss between host and device.